[xfdesktop-version-4.10.3+-rcfile_format]
4.10.3+=true

[/home/kylert/Desktop/Just A Little Bit Of Your Heart.mp3]
row=3
col=24

[/home/kylert/Desktop/Bugoy na Koykoy - Ang Bagal Ng Kotse Ko.mp4]
row=2
col=24

[/home/kylert/Desktop/The Initiative PH Backup]
row=1
col=24

[EEDE8292DE82532F]
row=0
col=24

