if status is-interactive
    # Commands to run in interactive sessions can go here
    
    alias ls="lsd --group-dirs first -h --icon-theme unicode -L"
    alias qw="cat to-do"
    alias eqw="vim to-do"
    export PF_INFO="ascii title os kernel uptime pkgs memory"

    
end
